@@ -19,7 +19,7 @@
 #'        other options).
 #' @param dede If \code{TRUE}, use the delayed differential equation solver,
 #'        which allows for time-lagged variables.
-#' @param new.mod If not running an integrated model type, a function with a new
+#' @param new.mod If not running an base model type, a function with a new
 #'        model to be simulated (see details).
 #' @param sens.param If \code{TRUE}, evaluate arguments in parameters with length
 #'        greater than 1 as sensitivity analyses, with one model run per value of
@@ -32,14 +32,14 @@
 #' @details
 #' \code{control.dcm} sets the required control settings for any deterministic
 #' compartmental models solved with the \code{\link{dcm}} function. Controls are
-#' required for both integrated model types and original models. For an overview of
-#' control settings for integrated DCM class models, consult the
+#' required for both base model types and original models. For an overview of
+#' control settings for base DCM class models, consult the
 #' \href{http://statnet.github.io/tut/BasicDCMs.html}{Basic DCMs} tutorial.
-#' For all integrated models, the \code{type} argument is a necessary parameter
+#' For all base models, the \code{type} argument is a necessary parameter
 #' and it has no default.
 #'
 #' @section New Model Functions:
-#' The form of the model function for integrated models may be displayed with the
+#' The form of the model function for base models may be displayed with the
 #' \code{print.mod} argument set to \code{TRUE}. In this case, the model will not
 #' be run. These model forms may be used as templates to write original model
 #' functions.
@@ -87,7 +87,7 @@ control.dcm <- function(type, nsteps, dt = 1, odemethod = "rk4",
   }
 
 
-  # Check type for integrated models
+  # Check type for base models
   if (is.null(p$new.mod)) {
     if (is.null(p$type) || !(p$type %in% c("SI", "SIS", "SIR"))) {
       stop("Specify type as \"SI\", \"SIS\", or \"SIR\" ", call. = FALSE)
@@ -146,7 +146,7 @@ control.dcm <- function(type, nsteps, dt = 1, odemethod = "rk4",
 #'        steps.
 #' @param skip.check If \code{TRUE}, skips the default error checking for the
 #'        structure and consistency of the parameter values, initial conditions,
-#'        and control settings before running integrated epidemic models. Setting
+#'        and control settings before running base epidemic models. Setting
 #'        this to \code{FALSE} is recommended when running models with new modules
 #'        specified.
 #' @param ... Additional control settings passed to model.
@@ -154,14 +154,14 @@ control.dcm <- function(type, nsteps, dt = 1, odemethod = "rk4",
 #' @details
 #' \code{control.icm} sets the required control settings for any stochastic
 #' individual contact model solved with the \code{\link{icm}} function. Controls
-#' are required for both integrated model types and when passing original process
-#' modules. For an overview of control settings for integrated ICM class models,
+#' are required for both base model types and when passing original process
+#' modules. For an overview of control settings for base ICM class models,
 #' consult the \href{http://statnet.github.io/tut/BasicICMs.html}{Basic ICMs}
-#' tutorial. For all integrated models, the \code{type} argument is a necessary
+#' tutorial. For all base models, the \code{type} argument is a necessary
 #' parameter and it has no default.
 #'
 #' @section New Modules:
-#' Integrated ICM models use a set of module functions that specify
+#' Base ICM models use a set of module functions that specify
 #' how the individual agents in the population are subjected to infection, recovery,
 #' demographics, and other processes. Core modules are those listed in the
 #' \code{.FUN} arguments. For each module, there is a default function used in
@@ -308,7 +308,7 @@ control.icm <- function(type, nsteps, nsims = 1, rec.rand = TRUE, b.rand = TRUE,
 #'        order in which they should be evaluated within each time step. If
 #'        \code{NULL}, the modules will be evaluated as follows: first any
 #'        new modules supplied through \code{...} in the order in which they are
-#'        listed, then the integrated modules in their order of the function listing.
+#'        listed, then the built-in modules in their order of the function listing.
 #'        The \code{initialize.FUN} will always be run first and the
 #'        \code{verbose.FUN} always last.
 #' @param set.control.stergm Control arguments passed to simulate.stergm. See the
@@ -331,7 +331,7 @@ control.icm <- function(type, nsteps, nsims = 1, rec.rand = TRUE, b.rand = TRUE,
 #'        is set to \code{TRUE}, this will only contain a static network with the
 #'        edge configuration at the final time step of each simulation.
 #' @param save.other A vector of elements on the \code{dat} master data list
-#'        to save out after each simulation. One example for integrated models is
+#'        to save out after each simulation. One example for base models is
 #'        the attribute list, "attr", at the final time step.
 #' @param verbose If \code{TRUE}, print model progress to the console.
 #' @param verbose.int Time step interval for printing progress to console, where
@@ -340,7 +340,7 @@ control.icm <- function(type, nsteps, nsims = 1, rec.rand = TRUE, b.rand = TRUE,
 #'        is to print progress after each time step.
 #' @param skip.check If \code{TRUE}, skips the default error checking for the
 #'        structure and consistency of the parameter values, initial conditions,
-#'        and control settings before running integrated epidemic models. Setting
+#'        and control settings before running base epidemic models. Setting
 #'        this to \code{FALSE} is recommended when running models with new modules
 #'        specified.
 #' @param ... Additional control settings passed to model.
@@ -348,10 +348,10 @@ control.icm <- function(type, nsteps, nsims = 1, rec.rand = TRUE, b.rand = TRUE,
 #' @details
 #' \code{control.net} sets the required control settings for any network model
 #' solved with the \code{\link{netsim}} function. Controls are required for both
-#' integrated model types and when passing original process modules. For an overview
-#' of control settings for integrated network models, consult the
+#' base model types and when passing original process modules. For an overview
+#' of control settings for base models, consult the
 #' \href{http://statnet.github.io/tut/BasicNet.html}{Basic Network Models} tutorial.
-#' For all integrated models, the \code{type} argument is a necessary parameter
+#' For all base models, the \code{type} argument is a necessary parameter
 #' and it has no default.
 #'
 #' @section The attr.rules Argument:
@@ -378,7 +378,7 @@ control.icm <- function(type, nsteps, nsims = 1, rec.rand = TRUE, b.rand = TRUE,
 #' in which case it is "s" (that is, all incoming nodes are susceptible).
 #'
 #' @section New Modules:
-#' Integrated network models use a set of module functions that specify how the
+#' Base network models use a set of module functions that specify how the
 #' individual nodes in the network are subjected to infection, recovery,
 #' demographics, and other processes. Core modules are those listed in the
 #' \code{.FUN} arguments. For each module, there is a default function used in
@@ -412,7 +412,7 @@ control.net <- function(type, nsteps, start = 1, nsims = 1, ncores = 1,
                         module.order = NULL, set.control.stergm,
                         save.nwstats = TRUE, nwstats.formula = "formation",
                         delete.nodes = FALSE, save.transmat = TRUE,
-                        save.network = TRUE, save.other, verbose = FALSE,
+                        save.network = TRUE, save.other, verbose = TRUE,
                         verbose.int = 1, skip.check = FALSE, ...) {
 
   # Get arguments
