@@ -1,7 +1,7 @@
 
 #' @title Deterministic Compartmental Model Functions
 #'
-#' @description These functions parameterize the integrated deterministic
+#' @description These functions parameterize the base deterministic
 #'              compartmental models solved using the \code{dcm} function.
 #'
 #' @param t Time vector, passed into model function internally through
@@ -13,8 +13,8 @@
 #'        \code{\link{dcm}} via the parameter settings in \code{\link{param.dcm}}.
 #'
 #' @details
-#' This help page shows the names of all the integrated deterministic compartmental
-#' model functions supported in EpiModel. Integrated models are those already
+#' This help page shows the names of all the base deterministic compartmental
+#' model functions supported in EpiModel. Base models are those already
 #' programmed interally within the software. The model functions may be printed
 #' to see their internal structure, either directly on the console or by using
 #' the \code{print.mod} argument in \code{\link{control.dcm}}.
@@ -465,7 +465,6 @@ mod_SIS_2g_cl <- function(t, t0, parms) {
     # Derivations
     num.g1 <- s.num + i.num
     num.g2 <- s.num.g2 + i.num.g2
-    num <- num.g1 + num.g2
 
     # Act Balancing
     if (balance == "g1") {
