@@ -18,13 +18,15 @@
 #' @param lty Line type for output lines.
 #' @param alpha Transparency level for lines, where 0 = transparent and 1 = opaque
 #'        (see \code{\link{transco}}).
-#' @param leg Type of legend to plot. Values are "n" for no legend, "full" for
+#' @param legend Type of legend to plot. Values are "n" for no legend, "full" for
 #'        full legend, and "lim" for limited legend (see details).
 #' @param leg.name Character string to use for legend, with the default
 #'        determined automatically based on the \code{y} input.
 #' @param leg.cex Legend scale size.
 #' @param axs Plot axis type (see \code{\link{par}} for details), with default
 #'        of "r".
+#' @param grid If \code{TRUE}, a grid is added to the background of plot
+#'        (see \code{\link{grid}} for details), with default of nx by ny.
 #' @param add If \code{TRUE}, new plot window is not called and lines are added to
 #'        existing plot window.
 #' @param ... Additional arguments to pass to main plot window (see
@@ -58,10 +60,10 @@
 #'
 #' @section Plot Legends:
 #' There are three automatic legend types available, and the legend is
-#' added by default for plots. To turn off the legend, use \code{leg="n"}. To
+#' added by default for plots. To turn off the legend, use \code{legend="n"}. To
 #' plot a legend with values for every line in a sensitivity analysis, use
-#' \code{leg="full"}. With models with many runs, this may be visually
-#' overwhelming. In those cases, use \code{leg="lim"} to plot a legend limited
+#' \code{legend="full"}. With models with many runs, this may be visually
+#' overwhelming. In those cases, use \code{legend="lim"} to plot a legend limited
 #' to the highest and lowest values of the varying parameter in the model. In cases
 #' where the default legend names are not helpful, one may override those names
 #' with the \code{leg.name} argument.
@@ -88,16 +90,16 @@
 #' plot(mod, y = "s.num", popfrac = TRUE, col = "Greys")
 #'
 #' # Plot number of susceptibles
-#' plot(mod, y = "s.num", popfrac = FALSE, col = "Greys")
+#' plot(mod, y = "s.num", popfrac = FALSE, col = "Greys", grid = TRUE)
 #'
 #' # Plot multiple runs of multiple compartments together
 #' plot(mod, y = c("s.num", "i.num"),
-#'      run = 5, xlim = c(0, 50))
+#'      run = 5, xlim = c(0, 50), grid = TRUE)
 #' plot(mod, y = c("s.num", "i.num"),
-#'      run = 10, lty = 2, leg = "n", add = TRUE)
+#'      run = 10, lty = 2, legend = "n", add = TRUE)
 #'
-plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg,
-                     leg.name, leg.cex = 0.8, axs = "r", add = FALSE, ...) {
+plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9,
+                     legend, leg.name, leg.cex = 0.8, axs = "r", grid = FALSE, add = FALSE, ...) {
 
   ## Set missing flags
   noy <- ifelse(missing(y), TRUE, FALSE)
@@ -105,7 +107,7 @@ plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg
   nocol <- ifelse(missing(col), TRUE, FALSE)
   nolwd <- ifelse(missing(lwd), TRUE, FALSE)
   nolty <- ifelse(missing(lty), TRUE, FALSE)
-  noleg <- ifelse(missing(leg), TRUE, FALSE)
+  noleg <- ifelse(missing(legend), TRUE, FALSE)
 
 
   ## Dot args
@@ -357,30 +359,34 @@ plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg
     }
   }
 
+  ## Grid
+  if (grid == TRUE) {
+     grid()
+  }
 
   ## Legend
 
   # Default legend type
   if (noleg == TRUE) {
-    leg <- "n"
+    legend <- "n"
     if (lcomp == 1 & nruns < 3) {
-      leg <- "full"
+      legend <- "full"
     }
     if (lcomp == 1 & nruns >= 3) {
-      leg <- "lim"
+      legend <- "lim"
     }
     if (lcomp > 1) {
-      leg <- "full"
+      legend <- "full"
     }
     if (noy == FALSE) {
-      leg <- "n"
+      legend <- "n"
     }
   } else {
-    if (leg == "lim" & nruns < 3) {
-      leg <- "full"
+    if (legend == "lim" & nruns < 3) {
+      legend <- "full"
     }
-    if (leg == "lim" & lcomp == 2) {
-      leg <- "full"
+    if (legend == "lim" & lcomp == 2) {
+      legend <- "full"
     }
   }
 
@@ -418,12 +424,12 @@ plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg
 
   # Legend
   if (norun == TRUE) {
-    if (leg == "full") {
+    if (legend == "full") {
       legend("topright", legend = leg.names,
              bg = "white", lty = lty, lwd = lwd,
              col = pal, cex = leg.cex)
     }
-    if (leg == "lim") {
+    if (legend == "lim") {
       legend("topright",
              legend = c(leg.names[1], "...", leg.names[nruns]),
              bg = "white",
@@ -431,7 +437,7 @@ plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg
              col = c(pal[1], "white", pal[nruns]), cex = leg.cex)
     }
   }
-  if (norun == FALSE & leg != "n") {
+  if (norun == FALSE & legend != "n") {
     if (lcomp == 1) {
       legend("topright", legend = leg.names,
              bg = "white", lty = lty[1:length(run)],
@@ -468,7 +474,7 @@ plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg
 #' control <- control.icm(type = "SIR", nsteps = 100,
 #'                        nsims = 3, verbose = FALSE)
 #' mod <- icm(param, init, control)
-#' plot(mod)
+#' plot(mod, grid = TRUE)
 #'
 #' ## Example 2: Plot only infected with specific output from SI model
 #' param <- param.icm(inf.prob = 0.25, act.rate = 0.25)
@@ -482,14 +488,14 @@ plot.dcm <- function(x, y, popfrac = FALSE, run, col, lwd, lty, alpha = 0.9, leg
 #'
 #' # Plot incidence
 #' par(mfrow = c(1, 2))
-#' plot(mod2, y = "si.flow", mean.smooth = TRUE)
+#' plot(mod2, y = "si.flow", mean.smooth = TRUE, grid = TRUE)
 #' plot(mod2, y = "si.flow", qnts.smooth = FALSE, qnts = 1)
 #'
 plot.icm <- function(x, y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col, sim.lwd,
                      sim.alpha, mean.line = TRUE, mean.smooth = TRUE,
                      mean.col, mean.lwd = 2, mean.lty = 1, qnts = 0.5, qnts.col,
-                     qnts.alpha, qnts.smooth = TRUE, leg, leg.cex = 0.8,
-                     axs = "r", add = FALSE, ...) {
+                     qnts.alpha, qnts.smooth = TRUE, legend, leg.cex = 0.8,
+                     axs = "r", grid = FALSE, add = FALSE, ...) {
 
   ## Model dimensions and class ##
   nsteps <- x$control$nsteps
@@ -524,8 +530,8 @@ plot.icm <- function(x, y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col, si
                grep(".num.g2$", names(x$epi), value = TRUE))
       }
     }
-    if (missing(leg)) {
-      leg <- TRUE
+    if (missing(legend)) {
+      legend <- TRUE
     }
   }
   if (nocomp == FALSE) {
@@ -553,7 +559,7 @@ plot.icm <- function(x, y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col, si
     qnts.col <- bpal
   }
   if (missing(qnts.alpha)) {
-    qnts.alpha <- 0.4
+    qnts.alpha <- 0.5
   }
   qnts.pal <- transco(qnts.col, qnts.alpha)
 
@@ -584,7 +590,6 @@ plot.icm <- function(x, y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col, si
 
   # Special case for 2-mode/group models
   if (modes == 2 & nocomp == TRUE) {
-    pal <- brewer.pal(3, "Set1")
     if (dis.type == "SIR") {
       mean.pal <- rep(mean.pal, 2)
       qnts.pal <- rep(qnts.pal, 2)
@@ -596,7 +601,6 @@ plot.icm <- function(x, y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col, si
     }
   }
 
-
   ## Prevalence calculations ##
   x <- denom(x, y, popfrac)
 
@@ -707,9 +711,13 @@ plot.icm <- function(x, y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col, si
     draw_means(x, y, mean.smooth, mean.lwd, mean.pal, mean.lty)
   }
 
+  ## Grid
+  if (grid == TRUE) {
+      grid()
+  }
 
   ## Legends ##
-  if (!missing(leg) && leg == TRUE) {
+  if (!missing(legend) && legend == TRUE) {
     if (modes == 2 & nocomp == TRUE) {
       leg.lty <- mean.lty
     } else {
@@ -841,7 +849,7 @@ draw_means <- function(x, y, mean.smooth, mean.lwd,
 #' # Only formation diagnostics are available to plot
 #' plot(dx1, stats = "edges")
 #' plot(dx1, stats = c("edges", "concurrent"))
-#' plot(dx1, stats = "edges", method = "b", col = "seagreen3")
+#' plot(dx1, stats = "edges", method = "b", col = "seagreen3", grid = TRUE)
 #' plot(dx1, stats = c("nodefactor.sex.0", "nodefactor.sex.1"),
 #'      method = "b", col = transco(2:3, 0.5))
 #'
@@ -853,25 +861,25 @@ draw_means <- function(x, y, mean.smooth, mean.lwd,
 #' dx2
 #'
 #' # Formation statistics plots, joined and separate
-#' plot(dx2)
+#' plot(dx2, grid = TRUE)
 #' plot(dx2, type = "formation", plots.joined = TRUE)
-#' plot(dx2, type = "formation", sim = 1, plots.joined = TRUE,
+#' plot(dx2, type = "formation", sims = 1, plots.joined = TRUE,
 #'      qnts = FALSE, sim.lines = TRUE, mean.line = FALSE)
 #' plot(dx2, type = "formation", plots.joined = FALSE,
-#'      stats = c("edges", "concurrent"))
+#'      stats = c("edges", "concurrent"), grid = TRUE)
 #' plot(dx2, type = "formation", stats = "nodefactor.sex.0",
-#'      sim = 1, sim.lwd = 5, sim.col = "darkmagenta")
+#'      sims = 1, sim.lwd = 5, sim.col = "darkmagenta")
 #'
-#' plot(dx2, method = "b", col = "bisque")
+#' plot(dx2, method = "b", col = "bisque", grid = TRUE)
 #' plot(dx2, method = "b", stats = "meandeg", col = "dodgerblue")
 #'
 #' # Duration statistics plot
-#' plot(dx2, type = "duration", mean.col = "black")
-#' plot(dx2, type = "duration", sim = 10, mean.line = FALSE, sim.line = TRUE,
+#' plot(dx2, type = "duration", mean.col = "black", grid = TRUE)
+#' plot(dx2, type = "duration", sims = 10, mean.line = FALSE, sim.line = TRUE,
 #'      sim.col = "steelblue", sim.lwd = 3, targ.lty = 1, targ.lwd = 0.5)
 #'
 #' # Dissolution statistics plot
-#' plot(dx2, type = "dissolution", mean.col = "black")
+#' plot(dx2, type = "dissolution", mean.col = "black", grid = TRUE)
 #' plot(dx2, type = "dissolution", method = "b", col = "pink1")
 #' }
 #'
@@ -880,7 +888,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
                        mean.smooth = TRUE, mean.col, mean.lwd = 2, mean.lty = 1,
                        qnts = 0.5, qnts.col, qnts.alpha, qnts.smooth = TRUE,
                        targ.line = TRUE, targ.col, targ.lwd = 2, targ.lty = 2,
-                       plots.joined, leg, ...) {
+                       plots.joined, legend, grid = FALSE, ...) {
 
   # Checks and Variables ----------------------------------------------------
 
@@ -980,7 +988,6 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
       }
     }
 
-
     ## Joined Plots
     if (method == "l") {
 
@@ -992,15 +999,20 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
         }
       }
 
+      ## Grid
+      if (grid == TRUE) {
+         grid()
+      }
+
       if (plots.joined == TRUE) {
 
         ## Default legend
         if (nstats == 1) {
-          if (missing(leg)) {
-            leg <- FALSE
+          if (missing(legend)) {
+            legend <- FALSE
           }
         } else {
-          leg <- TRUE
+          legend <- TRUE
         }
 
         ## Default ylim
@@ -1060,7 +1072,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
               qnts.col <- sim.col
             }
             if (missing(qnts.alpha)) {
-              qnts.alpha <- 0.35
+              qnts.alpha <- 0.5
             }
             qnts.col <- transco(qnts.col, qnts.alpha)
             quants <- c((1 - qnts) / 2, 1 - ((1 - qnts) / 2))
@@ -1107,7 +1119,14 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
           }
 
         }
-        if (leg == TRUE) {
+
+        ## Grid
+        if (grid == TRUE) {
+            grid()
+        }
+
+
+        if (legend == TRUE) {
           legend("topleft", legend = nmstats[outsts], lwd = 3,
                  col = sim.col[1:nstats], cex = 0.75, bg = "white")
         }
@@ -1152,7 +1171,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
               qnts.col <- sim.col
             }
             if (missing(qnts.alpha)) {
-              qnts.alpha <- 0.35
+              qnts.alpha <- 0.5
             }
             qnts.col <- transco(qnts.col, qnts.alpha)
             quants <- c((1 - qnts) / 2, 1 - ((1 - qnts) / 2))
@@ -1198,6 +1217,11 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
                      col = targ.col[which(j == outsts)])
             }
           }
+
+          ## Grid
+          if (grid == TRUE) {
+              grid()
+          }
         }
 
         # Reset graphical parameters
@@ -1220,6 +1244,10 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
           points(x = outsts[j], y = nwstats.table$Target[j],
                  pch = 16, cex = 1.5, col = "blue")
         }
+          ## Grid
+          if (grid == TRUE) {
+              grid()
+          }
       }
 
     }
@@ -1290,7 +1318,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
           qnts.col <- sim.col
         }
         if (missing(qnts.alpha)) {
-          qnts.alpha <- 0.35
+          qnts.alpha <- 0.5
         }
         qnts.col <- transco(qnts.col, qnts.alpha)
         quants <- c((1 - qnts) / 2, 1 - ((1 - qnts) / 2))
@@ -1335,6 +1363,11 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
                lty = targ.lty, lwd = targ.lwd,
                col = targ.col)
       }
+
+      ## Grid
+      if (grid == TRUE) {
+          grid()
+      }
     }
 
     if (method == "b") {
@@ -1342,6 +1375,12 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
       boxplot(data, ...)
       points(x = 1, y = as.numeric(x$coef.diss[2]),
              pch = 16, cex = 1.5, col = "blue")
+
+      ## Grid
+      if (grid == TRUE) {
+          grid()
+      }
+
     }
 
   }
@@ -1409,7 +1448,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
           qnts.col <- sim.col
         }
         if (missing(qnts.alpha)) {
-          qnts.alpha <- 0.35
+          qnts.alpha <- 0.5
         }
         qnts.col <- transco(qnts.col, qnts.alpha)
         quants <- c((1 - qnts) / 2, 1 - ((1 - qnts) / 2))
@@ -1451,6 +1490,11 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
         abline(h = as.numeric(1 / (x$coef.diss[2]$duration)),
                lty = targ.lty, lwd = targ.lwd, col = targ.col)
       }
+
+      ## Grid
+      if (grid == TRUE) {
+          grid()
+      }
     }
 
     if (method == "b") {
@@ -1458,10 +1502,13 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
       boxplot(data, ...)
       points(x = 1, y = as.numeric(1 / (x$coef.diss[2]$duration)),
              pch = 16, cex = 1.5, col = "blue")
+
+      ## Grid
+      if (grid == TRUE) {
+          grid()
+      }
     }
-
   }
-
 }
 
 
@@ -1502,10 +1549,12 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
 #' @param qnts.alpha Transparency level for quantile polygons, where 0 =
 #'        transparent and 1 = opaque (see \code{\link{transco}}).
 #' @param qnts.smooth If \code{TRUE}, use a lowess smoother on quantile polygons.
-#' @param leg If \code{TRUE}, plot default legend.
+#' @param legend If \code{TRUE}, plot default legend.
 #' @param leg.cex Legend scale size.
 #' @param axs Plot axis type (see \code{\link{par}} for details), with default
 #'        to \code{"r"}.
+#' @param grid If \code{TRUE}, a grid is added to the background of plot
+#'        (see \code{\link{grid}} for details), with default of nx by ny.
 #' @param add If \code{TRUE}, new plot window is not called and lines are added to
 #'        existing plot window.
 #' @param network Network number, for simulations with multiple networks
@@ -1615,7 +1664,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
 #' mod <- netsim(est, param, init, control)
 #'
 #' # Plot epidemic trajectory (default type)
-#' plot(mod, type = "epi")
+#' plot(mod, type = "epi", grid = TRUE)
 #' plot(mod, type = "epi", popfrac = TRUE)
 #' plot(mod, type = "epi", y = "si.flow", qnts = 1)
 #'
@@ -1637,7 +1686,7 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
 #'
 #' # Plot formation statistics
 #' par(mfrow = c(1,1), mar = c(3,3,1,1), mgp = c(2,1,0))
-#' plot(mod, type = "formation")
+#' plot(mod, type = "formation", grid = TRUE)
 #' plot(mod, type = "formation", plots.joined = FALSE)
 #' plot(mod, type = "formation", sims = 2:3)
 #' plot(mod, type = "formation", plots.joined = FALSE,
@@ -1648,8 +1697,8 @@ plot.netdx <- function(x, type = "formation", method = "l", sims, stats,
 plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE, sims, sim.col,
                         sim.lwd, sim.alpha, mean.line = TRUE, mean.smooth = TRUE,
                         mean.col, mean.lwd = 2, mean.lty = 1, qnts = 0.5, qnts.col,
-                        qnts.alpha, qnts.smooth = TRUE, leg, leg.cex = 0.8, axs = "r",
-                        add = FALSE, network = 1, at = 1, col.status = FALSE,
+                        qnts.alpha, qnts.smooth = TRUE, legend, leg.cex = 0.8, axs = "r",
+                        grid = FALSE, add = FALSE, network = 1, at = 1, col.status = FALSE,
                         shp.bip = NULL, stats, targ.line = TRUE, targ.col,
                         targ.lwd = 2, targ.lty = 2, plots.joined, ...) {
 
@@ -1796,8 +1845,8 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
                  grep(".num.m2$", names(x$epi), value = TRUE))
         }
       }
-      if (missing(leg)) {
-        leg <- TRUE
+      if (missing(legend)) {
+        legend <- TRUE
       }
     }
     if (nocomp == FALSE) {
@@ -1825,7 +1874,7 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
       qnts.col <- bpal
     }
     if (missing(qnts.alpha)) {
-      qnts.alpha <- 0.4
+      qnts.alpha <- 0.5
     }
     qnts.pal <- transco(qnts.col, qnts.alpha)
 
@@ -1991,9 +2040,13 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
       draw_means(x, y, mean.smooth, mean.lwd, mean.pal, mean.lty)
     }
 
+    ## Grid
+    if (grid == TRUE) {
+        grid()
+    }
 
     ## Legends ##
-    if (!missing(leg) && leg == TRUE) {
+    if (!missing(legend) && legend == TRUE) {
       if (modes == 2 & nocomp == TRUE) {
         leg.lty <- mean.lty
       } else {
@@ -2094,11 +2147,11 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
 
       ## Default legend
       if (nstats == 1) {
-        if (missing(leg)) {
-          leg <- FALSE
+        if (missing(legend)) {
+          legend <- FALSE
         }
       } else {
-        leg <- TRUE
+        legend <- TRUE
       }
 
       ## Default ylim
@@ -2160,7 +2213,7 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
             qnts.col <- sim.col
           }
           if (missing(qnts.alpha)) {
-            qnts.alpha <- 0.35
+            qnts.alpha <- 0.5
           }
           qnts.col <- transco(qnts.col, qnts.alpha)
           quants <- c((1 - qnts) / 2, 1 - ((1 - qnts) / 2))
@@ -2203,7 +2256,13 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
         }
 
       }
-      if (leg == TRUE) {
+
+      ## Grid
+      if (grid == TRUE) {
+          grid()
+      }
+
+      if (legend == TRUE) {
         legend("topleft", legend = nmstats[outsts], lwd = 3,
                col = sim.col[1:nstats], cex = 0.75, bg = "white")
       }
@@ -2250,7 +2309,7 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
             qnts.col <- sim.col
           }
           if (missing(qnts.alpha)) {
-            qnts.alpha <- 0.35
+            qnts.alpha <- 0.5
           }
           qnts.col <- transco(qnts.col, qnts.alpha)
           quants <- c((1 - qnts) / 2, 1 - ((1 - qnts) / 2))
@@ -2291,6 +2350,12 @@ plot.netsim <- function(x, type = "epi", y, popfrac = FALSE, sim.lines = FALSE,
                    col = targ.col[which(j == outsts)])
           }
         }
+
+        ## Grid
+        if (grid == TRUE) {
+            grid()
+        }
+
       }
 
       # Reset graphical parameters
