@@ -357,7 +357,7 @@ print.control.icm <- function(x, ...) {
   for (i in pToPrint) {
     cat(names(x)[i], "=", x[[i]], fill = 80)
   }
-  cat("Integrated Modules:", x$bi.mods, fill = 80)
+  cat("Base Modules:", x$bi.mods, fill = 80)
   if (length(x$user.mods) > 0) {
     cat("Extension Modules:", x$user.mods, fill = 80)
   }
@@ -386,7 +386,7 @@ print.control.net <- function(x, ...) {
       cat(names(x)[i], "=", x[[i]], fill = 80)
     }
   }
-  cat("Integrated Modules:", x$bi.mods, fill = 80)
+  cat("Base Modules:", x$bi.mods, fill = 80)
   if (length(x$user.mods) > 0) {
     cat("Extension Modules:", x$user.mods, fill = 80)
   }
