@@ -15,7 +15,7 @@ test_that("SI, 1G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -40,7 +40,7 @@ test_that("SI, 1G, CL: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -65,7 +65,7 @@ test_that("SI, 1G, CL: inf.prob = 0, status.rand = FALSE", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 13))
   expect_output(summary(x, at = 25), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -90,7 +90,7 @@ test_that("SI, 2G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -114,7 +114,7 @@ test_that("SI, 2G, CL: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -138,7 +138,7 @@ test_that("SI, 1G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -162,7 +162,7 @@ test_that("SI, 1G, OP: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -188,7 +188,7 @@ test_that("SI, 2G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -215,7 +215,7 @@ test_that("SI, 2G, OP: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -234,7 +234,7 @@ test_that("SIR, 1G, CL: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
-  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = TRUE,
+  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = FALSE,
                          verbose.int = 1)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -242,7 +242,7 @@ test_that("SIR, 1G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -258,14 +258,14 @@ test_that("SIR, 1G, CL: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
-  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = TRUE)
+  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -290,7 +290,7 @@ test_that("SIR, 1G, CL: inf.prob = 0, status.rand = FALSE", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 13))
   expect_output(summary(x, at = 10), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -315,7 +315,7 @@ test_that("SIR, 2G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -340,7 +340,7 @@ test_that("SIR, 2G, CL: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -364,7 +364,7 @@ test_that("SIR, 1G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -390,7 +390,7 @@ test_that("SIR, 1G, OP: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -419,7 +419,7 @@ test_that("SIR, 2G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -448,7 +448,7 @@ test_that("SIR, 2G, OP: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -475,7 +475,7 @@ test_that("SIS, 1G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -499,7 +499,7 @@ test_that("SIS, 1G, CL: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -522,7 +522,7 @@ test_that("SIS, 1G, CL: inf.prob = 0, status.rand = FALSE", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 13))
   expect_output(summary(x, at = 10), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -546,7 +546,7 @@ test_that("SIS, 2G, CL: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -569,7 +569,7 @@ test_that("SIS, 2G, CL: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -592,7 +592,7 @@ test_that("SIS, 1G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -616,7 +616,7 @@ test_that("SIS, 1G, OP: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -642,7 +642,7 @@ test_that("SIS, 2G, OP: 1 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 100), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
@@ -668,7 +668,7 @@ test_that("SIS, 2G, OP: 2 sim", {
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
   expect_is(as.data.frame(x, out = "mean"), "data.frame")
   expect_is(as.data.frame(x, out = "sd"), "data.frame")
-  expect_error(as.data.frame(x, out = vals, sim = 3))
+  expect_error(as.data.frame(x, out = "vals", sim = 3))
   expect_output(summary(x, at = 50), "EpiModel Summary")
   expect_error(summary(x, at = 200))
   plot(x)
